@@ -12,7 +12,7 @@
   ghyp.object <- fit.ghypmv(data = data, lambda = lambda, 
                             opt.pars = c(lambda = F, opt.pars), ...)
 
-  ghyp.object@parametrization <- "lambda.alpha.bar"
+  ghyp.object@parametrization <- "alpha.bar"
   ghyp.object@call <- call
   return(ghyp.object) 
 }
@@ -28,7 +28,7 @@
   ghyp.object <- fit.ghypmv(data = data, lambda = -0.5, 
                             opt.pars = c(lambda = F, opt.pars),...)
 
-  ghyp.object@parametrization <- "lambda.alpha.bar"
+  ghyp.object@parametrization <- "alpha.bar"
   ghyp.object@call <- call
   return(ghyp.object) 
 }
@@ -53,7 +53,7 @@
   ghyp.object <- fit.ghypmv(data = data, lambda = -nu/2, alpha.bar = 0, 
                             opt.pars = c(alpha.bar = F, opt.pars), ...)
 
-  ghyp.object@parametrization <- "lambda.alpha.bar"
+  ghyp.object@parametrization <- "alpha.bar"
   ghyp.object@call <- call
   return(ghyp.object) 
 }
@@ -72,7 +72,44 @@
   ghyp.object <- fit.ghypmv(data = data, lambda = lambda, alpha.bar = 0, 
                             opt.pars = c(alpha.bar = F, opt.pars), ...)
 
-  ghyp.object@parametrization <- "lambda.alpha.bar"
+  ghyp.object@parametrization <- "alpha.bar"
   ghyp.object@call <- call
   return(ghyp.object) 
 }
+#<--------------------------------   Gaussian   ------------------------------------>
+"fit.gaussmv" <- function(data, na.rm = T, save.data = T)
+{
+  call <- match.call() 
+  
+  data.mat <- check.data(data, case = "mv", na.rm = na.rm, fit = TRUE)
+
+  mu <- colMeans(data.mat, na.rm = na.rm)
+  sigma <- var(data.mat, na.rm = na.rm)
+
+  d <- length(mu)
+
+  if(!save.data){
+    data.mat <- NULL
+  } 
+  ghyp.object <- ghyp(lambda = as.numeric(NA), 
+                      chi = Inf, 
+                      psi = Inf,
+                      alpha.bar = NULL,
+                      mu = mu, 
+                      sigma = sigma, 
+                      gamma = rep(0, d),
+                      data = data.mat)
+
+  ghyp.object@parametrization <- "Gaussian"
+  ghyp.object@call <- call
+
+  llh <- sum(dghyp(data.mat, ghyp.object, logvalue = TRUE))
+
+  aic <- -2 * llh + d/2 * (d + 1) + d 
+  
+  return(fit.ghyp(ghyp.object, llh = llh, n.iter = 0,
+                  converged = TRUE,
+                  error.code = 0, error.message = "",
+                  parameter.variance = matrix(numeric(0)),
+                  fitted.params = c(mu = TRUE, sigma = TRUE), aic = aic))
+}
