@@ -3,6 +3,17 @@
   if(!is(object, "mle.ghyp")){
     stop("Object is not of class 'mle.ghyp'!")
   }
+
+  if(length(object@trace.pars) == 0){
+    trace.pars <- NULL
+  }else{
+    if(is.univariate(object)){
+      trace.pars <- as.data.frame(object@trace.pars)   
+    }else{
+      trace.pars <- object@trace.pars  
+    }
+  }
+  
   if(is.univariate(object)){
     return(list(logLikelihood = object@llh,
                 aic = object@aic,
@@ -11,7 +22,8 @@
                 n.iter = object@n.iter,
                 error.code = object@error.code,
                 error.message = object@error.message,
-                parameter.variance = object@parameter.variance))
+                parameter.variance = object@parameter.variance,
+                trace.pars = trace.pars))
                 
   }else{
     return(list(logLikelihood = object@llh,
@@ -20,7 +32,8 @@
                 converged = object@converged,
                 n.iter = object@n.iter,
                 error.code = object@error.code,
-                error.message = object@error.message))
+                error.message = object@error.message,
+                trace.pars = trace.pars))
 
   }
 }
