@@ -16,40 +16,42 @@
 
   if(gamma == 0){
     symm <- TRUE
-    tilt <- 0
-    Offset <- 0
+    skewness.scaled <- 0
+    skewness.norm <- 0
   } else {
     symm <- FALSE
-    tilt <- (x - mu) * (inv.sigma * gamma)
-    Offset <- gamma^2 * inv.sigma
+    skewness.scaled <- (x - mu) * (inv.sigma * gamma)
+    skewness.norm <- gamma^2 * inv.sigma
   }
   out <- NA
   if (psi == 0){
-    nu <- 2 * abs(lambda)
     if(symm){
-    # Symmetric student-t
-      log.const.top <- lgamma((nu + 1)/2)
-      log.const.bottom <- lgamma(nu/2) + 0.5 * log((nu - 2) * pi) + log(sigma)
-      log.top <- -(nu + 1)/2 * log(1 + Q/(nu - 2))
-      out <- log.const.top + log.top - log.const.bottom
+    # Symmetric Student-t
+      nu <- -2 * lambda
+      sigma.t <- sqrt((nu - 2) / nu) * sigma
+      out <- dt((x - mu) / sigma.t, df = nu, log = TRUE) - log(sigma.t)
     }else{
-    # Asymmetric student-t
-      interm <- sqrt((nu + Q - 2) * Offset)
-      log.top <- besselM3((nu + 1)/2, interm, logvalue = T) + tilt
-      log.const.top <- log(2) + (nu + 1)/4 * (log(Offset) - 
-                       log(Q + nu - 2)) + (nu/2) * log(nu/2 - 1)
-      log.const.bottom <- 0.5 * log(2 * pi) + log(sigma) + lgamma(nu/2)
-      out <- log.const.top + log.top - log.const.bottom
+    # Asymmetric Student-t
+      interm <- sqrt((chi + Q) * skewness.norm)
+      lambda.min.0.5 <- lambda - 0.5
+      
+      log.const.top <- -lambda * log(chi) - lambda.min.0.5 * log(skewness.norm)
+      log.const.bottom <- 0.5 * log(2 * pi) + log(sigma) + lgamma(-lambda) - (lambda + 1) * log(2)
+
+      log.top <- besselM3(lambda.min.0.5, interm, logvalue = TRUE) + skewness.scaled
+      log.bottom <- -lambda.min.0.5 * log(interm)
+
+      out <- log.const.top + log.top - log.const.bottom - log.bottom
     }
   }else if(psi > 0){
     if(chi > 0){
     # ghyp, hyp and NIG (symmetric and asymmetric)
-      log.top <- besselM3((lambda - 0.5), sqrt((psi + Offset) * (chi + Q)),logvalue = T) + tilt
-      log.bottom <- (0.5 - lambda) * log(sqrt((psi + Offset) * (chi + Q)))
+      log.top <- besselM3((lambda - 0.5), sqrt((psi + skewness.norm) * (chi + Q)),logvalue = TRUE) + skewness.scaled
+      log.bottom <- (0.5 - lambda) * log(sqrt((psi + skewness.norm) * (chi + Q)))
       log.const.top <- -lambda/2 * log(psi * chi) + 0.5 * log(psi) +
-                       (0.5 - lambda ) * log(1 + Offset/psi)
+                       (0.5 - lambda ) * log(1 + skewness.norm/psi)
       log.const.bottom <- 0.5 * log(2 * pi) +
-                          besselM3(lambda, sqrt(chi * psi),logvalue = T) + log(sigma)
+                          besselM3(lambda, sqrt(chi * psi),logvalue = TRUE) + log(sigma)
       out <- log.const.top + log.top - log.const.bottom - log.bottom
     }else if(chi == 0){
     # Variance gamma (symmetric and asymmetric)
@@ -62,13 +64,13 @@
     # any(Q < eps) & lambda == 0.5: Set Q[Q < eps] to NA 
       
       #<---------------  Internal function vg.density  ------------------>
-      vg.density <- function(Q, Offset, tilt, lambda, psi, sigma)
+      vg.density <- function(Q, skewness.norm, skewness.scaled, lambda, psi, sigma)
       {
-        log.top <- besselM3((lambda - 0.5), sqrt((psi + Offset) * Q),logvalue = T) + tilt
-        log.bottom <- (0.5 - lambda) * log(sqrt((psi + Offset) * Q))
+        log.top <- besselM3((lambda - 0.5), sqrt((psi + skewness.norm) * Q),logvalue = TRUE) + skewness.scaled
+        log.bottom <- (0.5 - lambda) * log(sqrt((psi + skewness.norm) * Q))
   
         log.const.top <- log(psi) * lambda + (1 - lambda) * log(2) +
-                         (0.5 - lambda) * log(psi + Offset)
+                         (0.5 - lambda) * log(psi + skewness.norm)
 
         log.const.bottom <- 0.5 * log(2 * pi) + lgamma(lambda) + log(sigma)
         return(log.const.top + log.top - log.const.bottom - log.bottom)
@@ -83,19 +85,19 @@
           warning("NA's generated in internal.dghyp: Some standardized observations are close to 0 ",
                   "and lambda is close to 0.5!")
           if(gamma == 0){
-            tmp.tilt <- 0
+            tmp.skewness.scaled <- 0
           }else{
-            tmp.tilt <- tilt[Q >= eps]
+            tmp.skewness.scaled <- skewness.scaled[Q >= eps]
           }
           out <- rep(NA, length(Q))
-          out[Q >= eps] <- vg.density(Q[Q >= eps], Offset, tmp.tilt, lambda, psi, sigma) 
+          out[Q >= eps] <- vg.density(Q[Q >= eps], skewness.norm, tmp.skewness.scaled, lambda, psi, sigma) 
         }else if(lambda > 0.5){ 
           message("Singularity (x-mu)==0: Interpolate with splines.")
 
           #<----------  Internal function vg.density.singular  -------------->
-          vg.density.singular <- function(Offset, lambda, psi, sigma)
+          vg.density.singular <- function(skewness.norm, lambda, psi, sigma)
           {
-            log.const.top <- log(psi) * lambda + (0.5 - lambda) * log(psi + Offset) + 
+            log.const.top <- log(psi) * lambda + (0.5 - lambda) * log(psi + skewness.norm) + 
                              lgamma(lambda - 0.5)
     
             log.const.bottom <- log(2) + 0.5 * log(pi) + lgamma(lambda) + log(sigma)
@@ -107,12 +109,12 @@
           out <- rep(0, length(Q))
 
           if(gamma == 0){
-            tmp.tilt <- 0
+            tmp.skewness.scaled <- 0
           }else{
-            tmp.tilt <- tilt[Q >= eps]
+            tmp.skewness.scaled <- skewness.scaled[Q >= eps]
           }
           
-          out[Q >= eps] <- vg.density(Q[Q >= eps], Offset, tmp.tilt, lambda, psi, sigma)
+          out[Q >= eps] <- vg.density(Q[Q >= eps], skewness.norm, tmp.skewness.scaled, lambda, psi, sigma)
           
           # Interpolate all observations < eps
           # x points
@@ -121,15 +123,15 @@
           
           # y points          
           if(gamma == 0){
-            tmp.tilt <- 0
+            tmp.skewness.scaled <- 0
           }else{
-            tmp.tilt <- (tmp.x - mu) * inv.sigma * gamma 
+            tmp.skewness.scaled <- (tmp.x - mu) * inv.sigma * gamma 
           }
           
           tmp.Q <- ((tmp.x - mu)/sigma)^2
-          tmp.density <-  vg.density(tmp.Q, Offset, tmp.tilt, lambda, psi, sigma)
+          tmp.density <-  vg.density(tmp.Q, skewness.norm, tmp.skewness.scaled, lambda, psi, sigma)
           
-          spline.y <- c(tmp.density[1:2], vg.density.singular(Offset, lambda, psi, sigma), 
+          spline.y <- c(tmp.density[1:2], vg.density.singular(skewness.norm, lambda, psi, sigma), 
                         tmp.density[3:4])
 
           vg.density.interp <- splinefun(spline.x, spline.y)
@@ -138,12 +140,12 @@
           Q[Q < eps] <- eps
           warning("Singularity: Some standardized observations are close to 0 (< ",
                   sprintf("% .6E", eps), ")! Observations set to ", 
-                  sprintf("% .6E", eps),".", immediate. = TRUE)
+                  sprintf("% .6E", eps), ".", immediate. = TRUE)
 
-          out <- vg.density(Q, Offset, tilt, lambda, psi, sigma)
+          out <- vg.density(Q, skewness.norm, skewness.scaled, lambda, psi, sigma)
         }
       }else{
-        out <- vg.density(Q, Offset, tilt, lambda, psi, sigma)
+        out <- vg.density(Q, skewness.norm, skewness.scaled, lambda, psi, sigma)
       }
     }
     else out <- NA
