@@ -1,10 +1,15 @@
-"stepAIC.ghyp" <- function(data, dist = c("ghyp", "hyp", "NIG", "VG", "t"),
+"stepAIC.ghyp" <- function(data, dist = c("ghyp", "hyp", "NIG", "VG", "t", "gauss"),
                            symmetric = NULL, ...)
 {
  call <- match.call(expand.dots = TRUE)
  dist <- match.arg(dist, several.ok = TRUE)
- tmp.data <- try(check.data(data, case = "uv", na.rm = T, fit = TRUE), silent = TRUE)
+ 
+ with.gauss <- "gauss" %in% dist
+ 
+ dist <- dist[!(dist == "gauss")]
+ 
  type <- "uv"
+ tmp.data <- try(check.data(data, case = "uv", na.rm = T, fit = TRUE), silent = TRUE)
  if(class(tmp.data) == "try-error"){
    tmp.data <- try(check.data(data, case = "mv", na.rm = T, fit = TRUE), silent = TRUE)
    type <- "mv"
@@ -20,7 +25,7 @@
     }else if(symmetric == TRUE){
       symm <- TRUE   
     }else{
-      stop("Argument 'asymmetric' must be in 'NULL', 'TRUE' or 'FALSE'!")
+      stop("Argument 'asymmetric' must be either 'NULL', 'TRUE' or 'FALSE'!")
    }
  }
  nbr.fits <- length(dist) * length(symm)
@@ -55,6 +60,7 @@
      call.args <- c(list(data = tmp.data), list(...), list(symmetric = symm[j]))
     
      tmp.fit <- do.call(function.names[i], call.args)
+    
      tmp.fit@call <- call
 
      tmp.params <- coef(tmp.fit, type = "alpha.bar")
@@ -73,11 +79,40 @@
                               tmp.fit.info$converged, tmp.fit.info$n.iter,
                               stringsAsFactors = FALSE)
    
-   fit.info[(j - 1) * length(dist) + i, ] <- tmp.result
-   fitted.objects[[(j - 1) * length(dist) + i]] <- tmp.fit
+     fit.info[(j - 1) * length(dist) + i, ] <- tmp.result
+     fitted.objects[[(j - 1) * length(dist) + i]] <- tmp.fit
    }
  }
+ 
+ if(with.gauss){
+   if(!is.null(list(...)$save.data)){
+     save.data <- list(...)$save.data
+   }else{
+     save.data <- T
+   }
+   if(!is.null(list(...)$na.rm)){
+     na.rm <- list(...)$na.rm
+   }else{
+     na.rm <- T
+   }   
+   cat("Currently fitting: gauss\n")
+   if(type == "uv"){
+      gauss.fit <- fit.gaussuv(tmp.data, save.data = save.data, na.rm = na.rm)
+      gauss.uv.params <- data.frame(gauss.fit@mu, gauss.fit@sigma, 0, stringsAsFactors = FALSE)
+      colnames(gauss.uv.params) <- colnames(uv.params)
+      uv.params <- rbind(uv.params, gauss.uv.params)   
+   }else{
+      gauss.fit <- fit.gaussmv(tmp.data, save.data = save.data, na.rm = na.rm)   
+   }
 
+   gauss.fit.info <- data.frame("gauss", TRUE, NA, Inf, AIC(gauss.fit), 
+                                logLik(gauss.fit), TRUE, 0, stringsAsFactors = FALSE)
+                                
+   colnames(gauss.fit.info) <- colnames(fit.info)
+   fit.info <- rbind(fit.info, gauss.fit.info)   
+   
+   fitted.objects <- c(fitted.objects, gauss.fit)
+ }
  if(type == "uv"){
    fit.info <- cbind(fit.info[, 1:4], uv.params, fit.info[, 5:8])
  } 
