@@ -6,7 +6,7 @@ test.ghyp <- function(object, case = c("ghyp", "univariate", "multivariate")){
   }
 
   if(case == "univariate"){
-    if(object@dimension != 1){
+    if(!is.univariate(object)){
       stop("'ghyp' object must be univariate (i.e. dimension == 1)!\n")
     }
   }else if(case == "multivariate"){
